@@ -62,6 +62,7 @@ eval "$(univention-config-registry shell | sed -e 's/^/declare -r _/')"
 # shellcheck disable=SC2154,SC2034
 declare -i major="${_version_version%.*}"
 declare -i minor="${_version_version#*.}"
+declare -i patchlevel="${_version_patchlevel}"
 pkgname="test-$$-${RANDOM}"
 # shellcheck disable=SC2034
 repoprefix="univention-repository"
@@ -124,11 +125,13 @@ case "${UT_VERBOSE-}" in
 	"") exec 3>/dev/null 4>/dev/null ;;
 	?*) exec 3>&2 4>&2 ;;
 esac
-C0='' C1='' C2='' && [ -n "${TERM:-}" ] && C0=$'\e[0m' C1=$'\e[1;36m' C2=$'\e[1;35m'
+C0='' C1='' C2='' && [ -n "${TERM:-}" ] && tty -s <&4 && C0=$'\e[0m' C1=$'\e[1;36m' C2=$'\e[1;35m'
 PS4="+${C1}\${BASH_SOURCE}${C0}:${C2}\${LINENO}${C0}:${C1}\${FUNCNAME[0]}${C0}@${C2}\${SECONDS}${C0}: "
 BASH_XTRACEFD=4
 set -x
 
+SELFDIR="$(readlink -f "$(dirname "$0")")"
+echo "SELFDIR=\"${SELFDIR}\"" >&3
 unset TMPDIR # Unset user-defines base-directroy for mktemp
 BASEDIR="$(mktemp -d -p /var/lib/ucs-test)"
 echo "BASEDIR=\"${BASEDIR}\"" >&3
@@ -392,7 +395,7 @@ mkpdir () { # Create package directory ${dir}
 				suite='errata'
 				;;
 			[1-9]*([0-9]).+([0-9])--component/*)
-				versions+=("${1%--*}-0")
+				versions+=("${1%--*}-${patchlevel}")
 				component_versions+=("${1}")
 			;;
 			maintained|unmaintained) parts+=("${1}") ;;
@@ -587,7 +590,7 @@ mkpkg () { # Create Package files in ${1} for packages in ${2}. Optional argumen
 		cd "${OLDPWD}" || return $?
 	done
 
-	python ./create_releases_json.py "$REPODIR"
+	python "${SELFDIR}/create_releases_json.py" "$REPODIR"
 }
 
 compress () { # compress file: <Packages|Sources>
@@ -750,7 +753,7 @@ checkapt () { # Check for apt.source statement ${1}: [--mirror] [[--]source] [/p
 			binary-i386|binary-amd64) shift ; continue ;;
 			main) shift ; continue ;;
 			/*) # shellcheck disable=SC2046
-				set -- "$@" $(python ./split_repo_path.py "${REPODIR}" "${1}") && shift  # IFS
+				set -- "$@" $(python "${SELFDIR}/split_repo_path.py" "${REPODIR}" "${1}") && shift  # IFS
 				continue
 				;;
 			*) echo "Unknown ${1}" >&2 ; cat $files; return 2 ;;
@@ -870,7 +873,7 @@ checksrc () {  # check Sources.xz: <dist> <section> <mirror> [upstream]
 	local dist="$1" section="$2" dst="$3" src="${4:-}"
 	# shellcheck disable=SC2046
 	"${COMPRESS[0]%=*}" -dc <"${dst}/dists/${dist}/${section}/${COMPRESS[0]/*=/Sources}" |
-		sed -nrf ./dsc2files.sed |
+		sed -nrf "${SELFDIR}/dsc2files.sed" |
 		while IFS=$'\n' read -r fn
 		do
 			[ -f "${dst}/${fn}" ] || return $?
