@@ -1,4 +1,4 @@
-#!/usr/share/ucs-test/runner /usr/bin/py.test
+#!/usr/share/ucs-test/runner /usr/bin/pytest-3 -s -l -vv
 # -*- coding: utf-8 -*-
 ## desc: test self registration
 ## tags: [apptest]
@@ -14,7 +14,7 @@
 import pytest
 import email
 import datetime
-from urlparse import urlparse, parse_qs
+from urllib.parse import urlparse, parse_qs
 
 from univention.admin.uldap import getAdminConnection
 from univention.admin.uexceptions import noObject
@@ -101,7 +101,7 @@ def _get_mail(mails, idx=-1):
 	assert mails.data, 'No mails have been captured in %s seconds' % (MAILS_TIMEOUT,)
 	assert idx < len(mails.data), 'Not enough mails have been captured to get mail of index: {}'.format(idx)
 	mail = email.message_from_string(mails.data[idx])
-	body = mail.get_payload(decode=True)
+	body = mail.get_payload(decode=True).decode('utf-8')
 	verification_links = []
 	for line in body.split():
 		if line.startswith('https://'):
